@@ -3,13 +3,13 @@
 
 int main(void)
 {
-	cfgbool_t verbose = cfg_false;
+	cfg_bool_t verbose = cfg_false;
 	char *server = strdup("gazonk");
 	double delay = 1.356e-32;
 	char *username = NULL;
 	int debug = 1;
 
-	cfgopt_t opts[] = {
+	cfg_opt_t opts[] = {
 		CFG_SIMPLE_BOOL("verbose", &verbose),
 		CFG_SIMPLE_STR("server", &server),
 		CFG_SIMPLE_STR("user", &username),
@@ -21,13 +21,22 @@ int main(void)
 
 	cfg = cfg_init(opts, 0);
 	cfg_parse(cfg, "simple.conf");
-	cfg_free(cfg);
 
 	printf("verbose: %s\n", verbose ? "true" : "false");
-	printf("server: %s (%s)\n", server, cfg_getstr(cfg, "server"));
+	printf("server: %s\n", server);
 	printf("username: %s\n", username);
 	printf("debug: %d\n", debug);
 	printf("delay: %G\n", delay);
 
+	printf("setting username to 'foo'\n");
+	/* using cfg_setstr here is not necessary at all, the equivalent
+	 * code is:
+	 *   free(username);
+	 *   username = strdup("foo");
+	 */
+	cfg_setstr(cfg, "user", "foo");
+	printf("username: %s\n", username);
+
+	cfg_free(cfg);
 	return 0;
 }
